@@ -228,17 +228,11 @@ terminal_app_encoding_list_notify_cb (GSettings   *settings,
   /* Mark all as non-active, then re-enable the active ones */
   g_hash_table_foreach (app->encodings, (GHFunc) encoding_mark_active, GUINT_TO_POINTER (FALSE));
 
-  /* First add the locale's charset */
-  encoding = g_hash_table_lookup (app->encodings, "current");
-  g_assert (encoding);
-  if (terminal_encoding_is_valid (encoding))
-    encoding->is_active = TRUE;
-
   /* Also always make UTF-8 available */
   encoding = g_hash_table_lookup (app->encodings, "UTF-8");
   g_assert (encoding);
-  if (terminal_encoding_is_valid (encoding))
-    encoding->is_active = TRUE;
+  g_assert (terminal_encoding_is_valid (encoding));
+  encoding->is_active = TRUE;
 
   g_settings_get (settings, key, "^as", &encodings);
   for (i = 0; encodings[i] != NULL; ++i) {
@@ -540,7 +534,6 @@ terminal_app_new_terminal (TerminalApp     *app,
                            TerminalWindow  *window,
                            GSettings       *profile,
                            char           **override_command,
-                           const char      *title,
                            const char      *working_dir,
                            char           **child_env,
                            double           zoom)
@@ -550,7 +543,7 @@ terminal_app_new_terminal (TerminalApp     *app,
   g_return_val_if_fail (TERMINAL_IS_APP (app), NULL);
   g_return_val_if_fail (TERMINAL_IS_WINDOW (window), NULL);
 
-  screen = terminal_screen_new (profile, override_command, title,
+  screen = terminal_screen_new (profile, override_command,
                                 working_dir, child_env, zoom);
 
   terminal_window_add_screen (window, screen, -1);
@@ -632,23 +625,6 @@ terminal_app_get_encodings (TerminalApp *app)
   return app->encodings;
 }
 
-static const char *
-charset_validated (const char *charset)
-{
-  gsize i;
-
-  if (charset == NULL)
-    return "current"; 
-
-  for (i = 0; charset[i] != '\0'; i++) {
-    char c = charset[i];
-    if (!(g_ascii_isalnum(c) || c == '_' || c == '-'))
-      return "UTF-8";
-  }
-
-  return charset;
-}
-
 /**
  * terminal_app_ensure_encoding:
  * @app:
@@ -659,7 +635,7 @@ charset_validated (const char *charset)
  * @charset is not a known charset, returns a #TerminalEncoding for a
  * custom charset.
  *
- * Returns: (transfer none): a #TerminalEncoding, or %NULL
+ * Returns: (transfer none): a #TerminalEncoding
  */
 TerminalEncoding *
 terminal_app_ensure_encoding (TerminalApp *app,
@@ -667,7 +643,7 @@ terminal_app_ensure_encoding (TerminalApp *app,
 {
   TerminalEncoding *encoding;
 
-  encoding = g_hash_table_lookup (app->encodings, charset_validated (charset));
+  encoding = g_hash_table_lookup (app->encodings, charset ? charset : "UTF-8");
   if (encoding == NULL)
     {
       encoding = terminal_encoding_new (charset,
@@ -675,7 +651,7 @@ terminal_app_ensure_encoding (TerminalApp *app,
                                         TRUE,
                                         TRUE /* scary! */);
       g_hash_table_insert (app->encodings,
-                          (gpointer) terminal_encoding_get_id (encoding),
+                          (gpointer) terminal_encoding_get_charset (encoding),
                           encoding);
     }
 
